HTTP状态码_继续 = 100  # 继续
HTTP状态码_切换协议 = 101  # 切换协议
HTTP状态码_处理 = 102  # 处理
HTTP状态码_请求成功 = 200  # 请求成功
HTTP状态码_已创建 = 201  # 已创建
HTTP状态码_已接受 = 202  # 已接受
HTTP状态码_非授权信息 = 203  # 非授权信息
HTTP状态码_无内容 = 204  # 无内容
HTTP状态码_重置内容 = 205  # 重置内容
HTTP状态码_部分内容 = 206  # 部分内容
HTTP状态码_多状态 = 207  # 多状态
HTTP状态码_已报告 = 208  # 已报告
HTTP状态码_IM使用 = 226  # IM使用
HTTP状态码_多种选择 = 300  # 多种选择
HTTP状态码_永久移动 = 301  # 永久移动
HTTP状态码_临时移动 = 302  # 临时移动
HTTP状态码_查看其他位置 = 303  # 查看其他位置
HTTP状态码_未修改 = 304  # 未修改
HTTP状态码_使用代理 = 305  # 使用代理
HTTP状态码_临时重定向 = 307  # 临时重定向
HTTP状态码_永久重定向 = 308  # 永久重定向
HTTP状态码_错误请求 = 400  # 错误请求
HTTP状态码_未授权 = 401  # 未授权
HTTP状态码_支付要求 = 402  # 支付要求
HTTP状态码_禁止 = 403  # 禁止
HTTP状态码_未找到 = 404  # 未找到
HTTP状态码_方法禁用 = 405  # 方法禁用
HTTP状态码_不接受 = 406  # 不接受
HTTP状态码_需要代理授权 = 407  # 需要代理授权
HTTP状态码_请求超时 = 408  # 请求超时
HTTP状态码_冲突 = 409  # 冲突
HTTP状态码_已删除 = 410  # 已删除
HTTP状态码_需要有效长度 = 411  # 需要有效长度
HTTP状态码_未满足前提条件 = 412  # 未满足前提条件
HTTP状态码_请求实体过大 = 413  # 请求实体过大
HTTP状态码_请求URI过长 = 414  # 请求URI过长
HTTP状态码_不支持的媒体类型 = 415  # 不支持的媒体类型
HTTP状态码_请求范围不符合要求 = 416  # 请求范围不符合要求
HTTP状态码_期望失败 = 417  # 期望失败
HTTP状态码_我是一个茶壶 = 418  # 我是一个茶壶
HTTP状态码_登录超时 = 419  # 登录超时
HTTP状态码_未经许可 = 421  # 未经许可
HTTP状态码_锁定 = 423  # 锁定
HTTP状态码_失败依赖 = 424  # 失败依赖
HTTP状态码_未升级 = 426  # 未升级
HTTP状态码_预留空间不足 = 428  # 预留空间不足
HTTP状态码_预期失败 = 429  # 预期失败
HTTP状态码_请求头字段太大 = 431  # 请求头字段太大
HTTP状态码_服务器内部错误 = 500  # 服务器内部错误
HTTP状态码_尚未实施 = 501  # 尚未实施
HTTP状态码_错误网关 = 502  # 错误网关
HTTP状态码_服务不可用 = 503  # 服务不可用
HTTP状态码_网关超时 = 504  # 网关超时
HTTP状态码_HTTP版本不受支持 = 505  # HTTP版本不受支持
HTTP状态码_变体也可协商 = 506  # 变体也可协商
HTTP状态码_存储不足 = 507  # 存储不足
HTTP状态码_循环引用 = 508  # 循环引用
HTTP状态码_带宽限制 = 509  # 带宽限制
HTTP状态码_未扩展 = 510  # 未扩展
HTTP状态码_网络身份验证要求 = 511  # 网络身份验证要求
