from .修改指定行内容 import 修改指定行内容
from .删除指定行 import 删除指定行
from .删除空行 import 删除空行
from .取关键词出现次数 import 取关键词出现次数
from .取指定行内容 import 取指定行内容
from .取指定行内容_分割 import 取指定行内容_分割
from .取指定行内容_取中间 import 取指定行内容_取中间
from .取指定行内容_取出现次数 import 取指定行内容_取出现次数
from .取指定行内容_取右边 import 取指定行内容_取右边
from .取指定行内容_取左边 import 取指定行内容_取左边
from .取指定行内容_取长度 import 取指定行内容_取长度
from .取行数 import 取行数
from .取首行无标记文本 import 取首行无标记文本
from .取首行无标记文本S import 取首行无标记文本S
from .指定行插入内容 import 指定行插入内容
from .替换指定内容 import 替换指定内容
from .统计字符数 import 统计字符数
from .读入全部内容 import 读入全部内容
from .读运行目录文件 import 读运行目录文件
from .追加内容 import 追加内容
from .重写内容 import 重写内容
