from setuptools import setup, find_packages

setup(
    name='zfx',
    version='2.0.51',
    packages=find_packages(),
    include_package_data=False,
    author='zengfengxiang',
    author_email='424491679@qq.com',
    description='[小提示：在pycharm导入模块后记得调整以名称排序，这样功能就是分好类的状态]中国人自己的模块！ZFX是一个多功能的Python工具包,提供了各种实用工具和功能，包括网络请求、剪贴板操作、系统监控、网页自动化、系统操作、文本处理、文件操作等,无论是日常办公还是自动化脚本，ZFX都能为您提供便捷的解决方案，让您的编程体验更加愉快！☆目前已有的功能分类：【excel】【html】【json】【列表】【打印】【抛出异常】【类型转换】【文件】【文本】【文本文件】【模块】【目录】【算数】【系统】【线程】【编码】【网页协议】【谷歌填表】【进制转换】【邮件IMAP】【邮件POP3】',
    long_description="""
    免责声明:
    本模块是“按原样”提供的，没有任何明示或暗示的保证。在任何情况下，作者或版权持有者均不对因使用本模块而产生的任何索赔、损害或其他责任负责，无论是在合同、侵权或其他情况下。

    使用本模块即表示接受此免责声明。如果您不同意此免责声明的任何部分，请勿使用本模块。

    本模块仅供参考和学习用途，用户需自行承担使用本模块的风险。作者对因使用本模块而造成的任何直接或间接损害不承担任何责任。

    作者保留随时更新本免责声明的权利，恕不另行通知。最新版本的免责声明将在模块的最新版本中提供。
    """,
    url='',
    install_requires=[
        'selenium',  # 用于支持库：谷歌填表
        'pyotp',  # 用于支持库：谷歌填表
        'mysql-connector-python',  # 用于支持库：mysql 在使用的时候导入的是mysql.connector实际上安装应该是mysql-connector-python才对(官方包)
        'pyinstaller',  # 用于支持库：文件 编译时会调用
        'pyperclip',  # 用于支持库：系统
        'requests',  # 用于支持库：系统 - 获取外网IP
        'psutil',  # 用于支持库：进程 （如 获取PID、命令行、线程数、进程路径等）
        # 添加其他依赖库
    ],
)
